from chaukas.spec.common.v1 import events_pb2 as _events_pb2
from chaukas.spec.common.v1 import query_pb2 as _query_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HealthzRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class HealthzResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetCapabilitiesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetCapabilitiesResponse(_message.Message):
    __slots__ = ()
    CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    capabilities: _query_pb2.Capabilities
    def __init__(self, capabilities: _Optional[_Union[_query_pb2.Capabilities, _Mapping]] = ...) -> None: ...

class IngestEventRequest(_message.Message):
    __slots__ = ()
    EVENT_FIELD_NUMBER: _ClassVar[int]
    event: _events_pb2.Event
    def __init__(self, event: _Optional[_Union[_events_pb2.Event, _Mapping]] = ...) -> None: ...

class IngestEventResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class IngestEventBatchRequest(_message.Message):
    __slots__ = ()
    EVENT_BATCH_FIELD_NUMBER: _ClassVar[int]
    event_batch: _events_pb2.EventBatch
    def __init__(self, event_batch: _Optional[_Union[_events_pb2.EventBatch, _Mapping]] = ...) -> None: ...

class IngestEventBatchResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryEventsRequest(_message.Message):
    __slots__ = ()
    QUERY_FIELD_NUMBER: _ClassVar[int]
    query: _query_pb2.QueryRequest
    def __init__(self, query: _Optional[_Union[_query_pb2.QueryRequest, _Mapping]] = ...) -> None: ...

class QueryEventsResponse(_message.Message):
    __slots__ = ()
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    response: _query_pb2.QueryResponse
    def __init__(self, response: _Optional[_Union[_query_pb2.QueryResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: chaukas/spec/client/v1/client.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'chaukas/spec/client/v1/client.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chaukas.spec.common.v1 import events_pb2 as chaukas_dot_spec_dot_common_dot_v1_dot_events__pb2
from chaukas.spec.common.v1 import query_pb2 as chaukas_dot_spec_dot_common_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#chaukas/spec/client/v1/client.proto\x12\x16\x63haukas.spec.client.v1\x1a#chaukas/spec/common/v1/events.proto\x1a\"chaukas/spec/common/v1/query.proto\"\x10\n\x0eHealthzRequest\"\x11\n\x0fHealthzResponse\"\x18\n\x16GetCapabilitiesRequest\"c\n\x17GetCapabilitiesResponse\x12H\n\x0c\x63\x61pabilities\x18\x01 \x01(\x0b\x32$.chaukas.spec.common.v1.CapabilitiesR\x0c\x63\x61pabilities\"I\n\x12IngestEventRequest\x12\x33\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1d.chaukas.spec.common.v1.EventR\x05\x65vent\"\x15\n\x13IngestEventResponse\"^\n\x17IngestEventBatchRequest\x12\x43\n\x0b\x65vent_batch\x18\x01 \x01(\x0b\x32\".chaukas.spec.common.v1.EventBatchR\neventBatch\"\x1a\n\x18IngestEventBatchResponse\"P\n\x12QueryEventsRequest\x12:\n\x05query\x18\x01 \x01(\x0b\x32$.chaukas.spec.common.v1.QueryRequestR\x05query\"X\n\x13QueryEventsResponse\x12\x41\n\x08response\x18\x01 \x01(\x0b\x32%.chaukas.spec.common.v1.QueryResponseR\x08response2\xad\x04\n\x14\x43haukasClientService\x12Z\n\x07Healthz\x12&.chaukas.spec.client.v1.HealthzRequest\x1a\'.chaukas.spec.client.v1.HealthzResponse\x12r\n\x0fGetCapabilities\x12..chaukas.spec.client.v1.GetCapabilitiesRequest\x1a/.chaukas.spec.client.v1.GetCapabilitiesResponse\x12\x66\n\x0bIngestEvent\x12*.chaukas.spec.client.v1.IngestEventRequest\x1a+.chaukas.spec.client.v1.IngestEventResponse\x12u\n\x10IngestEventBatch\x12/.chaukas.spec.client.v1.IngestEventBatchRequest\x1a\x30.chaukas.spec.client.v1.IngestEventBatchResponse\x12\x66\n\x0bQueryEvents\x12*.chaukas.spec.client.v1.QueryEventsRequest\x1a+.chaukas.spec.client.v1.QueryEventsResponseB=Z;github.com/chaukasai/chaukas-spec/chaukas/spec/client/v1;v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chaukas.spec.client.v1.client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/chaukasai/chaukas-spec/chaukas/spec/client/v1;v1'
  _globals['_HEALTHZREQUEST']._serialized_start=136
  _globals['_HEALTHZREQUEST']._serialized_end=152
  _globals['_HEALTHZRESPONSE']._serialized_start=154
  _globals['_HEALTHZRESPONSE']._serialized_end=171
  _globals['_GETCAPABILITIESREQUEST']._serialized_start=173
  _globals['_GETCAPABILITIESREQUEST']._serialized_end=197
  _globals['_GETCAPABILITIESRESPONSE']._serialized_start=199
  _globals['_GETCAPABILITIESRESPONSE']._serialized_end=298
  _globals['_INGESTEVENTREQUEST']._serialized_start=300
  _globals['_INGESTEVENTREQUEST']._serialized_end=373
  _globals['_INGESTEVENTRESPONSE']._serialized_start=375
  _globals['_INGESTEVENTRESPONSE']._serialized_end=396
  _globals['_INGESTEVENTBATCHREQUEST']._serialized_start=398
  _globals['_INGESTEVENTBATCHREQUEST']._serialized_end=492
  _globals['_INGESTEVENTBATCHRESPONSE']._serialized_start=494
  _globals['_INGESTEVENTBATCHRESPONSE']._serialized_end=520
  _globals['_QUERYEVENTSREQUEST']._serialized_start=522
  _globals['_QUERYEVENTSREQUEST']._serialized_end=602
  _globals['_QUERYEVENTSRESPONSE']._serialized_start=604
  _globals['_QUERYEVENTSRESPONSE']._serialized_end=692
  _globals['_CHAUKASCLIENTSERVICE']._serialized_start=695
  _globals['_CHAUKASCLIENTSERVICE']._serialized_end=1252
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: chaukas/spec/common/v1/events.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'chaukas/spec/common/v1/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#chaukas/spec/common/v1/events.proto\x12\x16\x63haukas.spec.common.v1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"m\n\x0eMessageContent\x12\x12\n\x04role\x18\x01 \x01(\tR\x04role\x12\x12\n\x04text\x18\x02 \x01(\tR\x04text\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\"\xaf\x01\n\x08ToolCall\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x35\n\targuments\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\targuments\x12#\n\rauth_required\x18\x04 \x01(\x08R\x0c\x61uthRequired\x12#\n\rfunction_name\x18\x05 \x01(\tR\x0c\x66unctionName\"\xd3\x01\n\x0cToolResponse\x12 \n\x0ctool_call_id\x18\x01 \x01(\tR\ntoolCallId\x12/\n\x06output\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x06output\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\x12*\n\x11\x65xecution_time_ms\x18\x04 \x01(\x01R\x0f\x65xecutionTimeMs\x12\x1f\n\x0bhttp_status\x18\x05 \x01(\x05R\nhttpStatus\"\x84\x05\n\rLLMInvocation\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x31\n\x07request\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07request\x12\x33\n\x08response\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x08response\x12#\n\rprompt_tokens\x18\x05 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x06 \x01(\x05R\x10\x63ompletionTokens\x12!\n\x0ctotal_tokens\x18\x07 \x01(\x05R\x0btotalTokens\x12 \n\x0btemperature\x18\x08 \x01(\x01R\x0btemperature\x12\x1d\n\nmax_tokens\x18\t \x01(\x05R\tmaxTokens\x12\x13\n\x05top_p\x18\n \x01(\x01R\x04topP\x12+\n\x11\x66requency_penalty\x18\x0b \x01(\x01R\x10\x66requencyPenalty\x12)\n\x10presence_penalty\x18\x0c \x01(\x01R\x0fpresencePenalty\x12\x39\n\nstart_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x1f\n\x0b\x64uration_ms\x18\x0f \x01(\x01R\ndurationMs\x12#\n\rfinish_reason\x18\x10 \x01(\tR\x0c\x66inishReason\"\x80\x01\n\x0ePolicyDecision\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\x12\x18\n\x07outcome\x18\x02 \x01(\tR\x07outcome\x12\x19\n\x08rule_ids\x18\x03 \x03(\tR\x07ruleIds\x12\x1c\n\trationale\x18\x04 \x01(\tR\trationale\"\x93\x01\n\nDataAccess\x12\x1e\n\ndatasource\x18\x01 \x01(\tR\ndatasource\x12!\n\x0c\x64ocument_ids\x18\x02 \x03(\tR\x0b\x64ocumentIds\x12\x1b\n\tchunk_ids\x18\x03 \x03(\tR\x08\x63hunkIds\x12%\n\x0epii_categories\x18\x04 \x03(\tR\rpiiCategories\"X\n\rRedactionInfo\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\x12\x16\n\x06method\x18\x02 \x01(\tR\x06method\x12\x17\n\x07salt_id\x18\x03 \x01(\tR\x06saltId\"`\n\tRetryInfo\x12\x18\n\x07\x61ttempt\x18\x01 \x01(\x05R\x07\x61ttempt\x12\x1a\n\x08strategy\x18\x02 \x01(\tR\x08strategy\x12\x1d\n\nbackoff_ms\x18\x03 \x01(\x05R\tbackoffMs\"\xb2\x01\n\x12PerformanceMetrics\x12\x1f\n\x0b\x63pu_percent\x18\x01 \x01(\x01R\ncpuPercent\x12\x1b\n\tmemory_mb\x18\x02 \x01(\x01R\x08memoryMb\x12\x1f\n\x0b\x64uration_ms\x18\x03 \x01(\x01R\ndurationMs\x12\x1e\n\nthroughput\x18\x04 \x01(\x01R\nthroughput\x12\x1d\n\nlatency_ms\x18\x05 \x01(\x01R\tlatencyMs\"\xbf\x01\n\x15InfrastructureMetrics\x12#\n\rresource_type\x18\x01 \x01(\tR\x0cresourceType\x12\x31\n\x07metrics\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x07metrics\x12\x12\n\x04host\x18\x03 \x01(\tR\x04host\x12\x1d\n\nprocess_id\x18\x04 \x01(\x05R\tprocessId\x12\x1b\n\tthread_id\x18\x05 \x01(\tR\x08threadId\"\x8d\x03\n\x0b\x43ostDetails\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x18\n\x07service\x18\x02 \x01(\tR\x07service\x12!\n\x0cinput_tokens\x18\x03 \x01(\x05R\x0binputTokens\x12#\n\routput_tokens\x18\x04 \x01(\x05R\x0coutputTokens\x12!\n\x0ctotal_tokens\x18\x05 \x01(\x05R\x0btotalTokens\x12\x1d\n\ninput_cost\x18\x06 \x01(\x01R\tinputCost\x12\x1f\n\x0boutput_cost\x18\x07 \x01(\x01R\noutputCost\x12\x1d\n\ntotal_cost\x18\x08 \x01(\x01R\ttotalCost\x12\x1a\n\x08\x63urrency\x18\t \x01(\tR\x08\x63urrency\x12/\n\x14input_rate_per_token\x18\n \x01(\x01R\x11inputRatePerToken\x12\x31\n\x15output_rate_per_token\x18\x0b \x01(\x01R\x12outputRatePerToken\"\x95\x02\n\x0c\x41gentHandoff\x12\"\n\rfrom_agent_id\x18\x01 \x01(\tR\x0b\x66romAgentId\x12&\n\x0f\x66rom_agent_name\x18\x02 \x01(\tR\rfromAgentName\x12\x1e\n\x0bto_agent_id\x18\x03 \x01(\tR\ttoAgentId\x12\"\n\rto_agent_name\x18\x04 \x01(\tR\x0btoAgentName\x12:\n\x0chandoff_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x0bhandoffData\x12\x16\n\x06reason\x18\x06 \x01(\tR\x06reason\x12!\n\x0chandoff_type\x18\x07 \x01(\tR\x0bhandoffType\"\xbe\x02\n\x07MCPCall\x12\x1f\n\x0bserver_name\x18\x01 \x01(\tR\nserverName\x12\x1d\n\nserver_url\x18\x02 \x01(\tR\tserverUrl\x12\x1c\n\toperation\x18\x03 \x01(\tR\toperation\x12\x16\n\x06method\x18\x04 \x01(\tR\x06method\x12\x31\n\x07request\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x07request\x12\x33\n\x08response\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructR\x08response\x12)\n\x10protocol_version\x18\x07 \x01(\tR\x0fprotocolVersion\x12*\n\x11\x65xecution_time_ms\x18\x08 \x01(\x01R\x0f\x65xecutionTimeMs\"\xbb\x01\n\tErrorInfo\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\x12\x1d\n\nerror_code\x18\x02 \x01(\tR\terrorCode\x12\x1f\n\x0bstack_trace\x18\x03 \x01(\tR\nstackTrace\x12 \n\x0brecoverable\x18\x04 \x01(\x08R\x0brecoverable\x12\'\n\x0frecovery_action\x18\x05 \x01(\tR\x0erecoveryAction\"\xed\x0f\n\x05\x45vent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1b\n\ttenant_id\x18\x02 \x01(\tR\x08tenantId\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12\x1d\n\nsession_id\x18\x04 \x01(\tR\tsessionId\x12\x17\n\x07span_id\x18\x05 \x01(\tR\x06spanId\x12$\n\x0eparent_span_id\x18\x06 \x01(\tR\x0cparentSpanId\x12\x35\n\x04type\x18\x07 \x01(\x0e\x32!.chaukas.spec.common.v1.EventTypeR\x04type\x12<\n\x08severity\x18\x08 \x01(\x0e\x32 .chaukas.spec.common.v1.SeverityR\x08severity\x12;\n\x06status\x18\t \x01(\x0e\x32#.chaukas.spec.common.v1.EventStatusR\x06status\x12\x36\n\x06\x61uthor\x18\n \x01(\x0e\x32\x1e.chaukas.spec.common.v1.AuthorR\x06\x61uthor\x12\x38\n\ttimestamp\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x19\n\x08\x61gent_id\x18\x0c \x01(\tR\x07\x61gentId\x12\x1d\n\nagent_name\x18\r \x01(\tR\tagentName\x12#\n\rinvocation_id\x18\x0e \x01(\tR\x0cinvocationId\x12\x1f\n\x0bresponse_id\x18\x0f \x01(\tR\nresponseId\x12\x1d\n\nis_partial\x18\x10 \x01(\x08R\tisPartial\x12\x19\n\x08is_final\x18\x11 \x01(\x08R\x07isFinal\x12\x1b\n\thash_prev\x18\x12 \x01(\tR\x08hashPrev\x12!\n\x0c\x63ontent_hash\x18\x13 \x01(\tR\x0b\x63ontentHash\x12\"\n\rworm_proof_id\x18\x14 \x01(\tR\x0bwormProofId\x12\x16\n\x06\x62ranch\x18\x15 \x01(\tR\x06\x62ranch\x12\x12\n\x04tags\x18\x16 \x03(\tR\x04tags\x12\x19\n\x08trace_id\x18\x17 \x01(\tR\x07traceId\x12\x42\n\x07message\x18\x1e \x01(\x0b\x32&.chaukas.spec.common.v1.MessageContentH\x00R\x07message\x12?\n\ttool_call\x18\x1f \x01(\x0b\x32 .chaukas.spec.common.v1.ToolCallH\x00R\x08toolCall\x12K\n\rtool_response\x18  \x01(\x0b\x32$.chaukas.spec.common.v1.ToolResponseH\x00R\x0ctoolResponse\x12N\n\x0ellm_invocation\x18! \x01(\x0b\x32%.chaukas.spec.common.v1.LLMInvocationH\x00R\rllmInvocation\x12@\n\x06policy\x18\" \x01(\x0b\x32&.chaukas.spec.common.v1.PolicyDecisionH\x00R\x06policy\x12\x45\n\x0b\x64\x61ta_access\x18# \x01(\x0b\x32\".chaukas.spec.common.v1.DataAccessH\x00R\ndataAccess\x12<\n\x0cstate_update\x18$ \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x0bstateUpdate\x12\x39\n\x05\x65rror\x18% \x01(\x0b\x32!.chaukas.spec.common.v1.ErrorInfoH\x00R\x05\x65rror\x12K\n\ragent_handoff\x18& \x01(\x0b\x32$.chaukas.spec.common.v1.AgentHandoffH\x00R\x0c\x61gentHandoff\x12<\n\x08mcp_call\x18\' \x01(\x0b\x32\x1f.chaukas.spec.common.v1.MCPCallH\x00R\x07mcpCall\x12\x37\n\x05retry\x18< \x01(\x0b\x32!.chaukas.spec.common.v1.RetryInfoR\x05retry\x12\x43\n\tredaction\x18= \x01(\x0b\x32%.chaukas.spec.common.v1.RedactionInfoR\tredaction\x12%\n\x0epii_categories\x18> \x03(\tR\rpiiCategories\x12L\n\x0bperformance\x18\x46 \x01(\x0b\x32*.chaukas.spec.common.v1.PerformanceMetricsR\x0bperformance\x12U\n\x0einfrastructure\x18G \x01(\x0b\x32-.chaukas.spec.common.v1.InfrastructureMetricsR\x0einfrastructure\x12\x37\n\x04\x63ost\x18H \x01(\x0b\x32#.chaukas.spec.common.v1.CostDetailsR\x04\x63ost\x12\x33\n\x08metadata\x18Z \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12\x34\n\nextensions\x18\x63 \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensionsB\t\n\x07\x63ontent\"\xbb\x02\n\nEventBatch\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\tR\x07\x62\x61tchId\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x35\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1d.chaukas.spec.common.v1.EventR\x06\x65vents\x12\x33\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12\x1d\n\ntotal_cost\x18\n \x01(\x01R\ttotalCost\x12!\n\x0ctotal_tokens\x18\x0b \x01(\x05R\x0btotalTokens\x12*\n\x11total_duration_ms\x18\x0c \x01(\x01R\x0ftotalDurationMs*\xd5\x04\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45VENT_TYPE_SESSION_START\x10\x01\x12\x1a\n\x16\x45VENT_TYPE_SESSION_END\x10\x02\x12\x1a\n\x16\x45VENT_TYPE_AGENT_START\x10\n\x12\x18\n\x14\x45VENT_TYPE_AGENT_END\x10\x0b\x12\x1c\n\x18\x45VENT_TYPE_AGENT_HANDOFF\x10\x0c\x12%\n!EVENT_TYPE_MODEL_INVOCATION_START\x10\x14\x12#\n\x1f\x45VENT_TYPE_MODEL_INVOCATION_END\x10\x15\x12\x1e\n\x1a\x45VENT_TYPE_TOOL_CALL_START\x10\x16\x12\x1c\n\x18\x45VENT_TYPE_TOOL_CALL_END\x10\x17\x12\x1d\n\x19\x45VENT_TYPE_MCP_CALL_START\x10\x18\x12\x1b\n\x17\x45VENT_TYPE_MCP_CALL_END\x10\x19\x12\x1d\n\x19\x45VENT_TYPE_INPUT_RECEIVED\x10\x1e\x12\x1d\n\x19\x45VENT_TYPE_OUTPUT_EMITTED\x10\x1f\x12\x14\n\x10\x45VENT_TYPE_ERROR\x10(\x12\x14\n\x10\x45VENT_TYPE_RETRY\x10)\x12\x1e\n\x1a\x45VENT_TYPE_POLICY_DECISION\x10<\x12\x1a\n\x16\x45VENT_TYPE_DATA_ACCESS\x10=\x12\x1b\n\x17\x45VENT_TYPE_STATE_UPDATE\x10>\x12\x15\n\x11\x45VENT_TYPE_SYSTEM\x10?*\xb4\x01\n\x0b\x45ventStatus\x12\x1c\n\x18\x45VENT_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45VENT_STATUS_STARTED\x10\x01\x12\x1c\n\x18\x45VENT_STATUS_IN_PROGRESS\x10\x02\x12\x1a\n\x16\x45VENT_STATUS_COMPLETED\x10\x03\x12\x17\n\x13\x45VENT_STATUS_FAILED\x10\x04\x12\x1a\n\x16\x45VENT_STATUS_CANCELLED\x10\x05*r\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x12\n\x0eSEVERITY_DEBUG\x10\x01\x12\x11\n\rSEVERITY_INFO\x10\x02\x12\x11\n\rSEVERITY_WARN\x10\x03\x12\x12\n\x0eSEVERITY_ERROR\x10\x04*w\n\x06\x41uthor\x12\x16\n\x12\x41UTHOR_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x41UTHOR_USER\x10\x01\x12\x10\n\x0c\x41UTHOR_AGENT\x10\x02\x12\x0f\n\x0b\x41UTHOR_TOOL\x10\x03\x12\x11\n\rAUTHOR_SYSTEM\x10\x04\x12\x0e\n\nAUTHOR_LLM\x10\x05\x42=Z;github.com/chaukasai/chaukas-spec/chaukas/spec/common/v1;v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chaukas.spec.common.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/chaukasai/chaukas-spec/chaukas/spec/common/v1;v1'
  _globals['_EVENTTYPE']._serialized_start=5689
  _globals['_EVENTTYPE']._serialized_end=6286
  _globals['_EVENTSTATUS']._serialized_start=6289
  _globals['_EVENTSTATUS']._serialized_end=6469
  _globals['_SEVERITY']._serialized_start=6471
  _globals['_SEVERITY']._serialized_end=6585
  _globals['_AUTHOR']._serialized_start=6587
  _globals['_AUTHOR']._serialized_end=6706
  _globals['_MESSAGECONTENT']._serialized_start=153
  _globals['_MESSAGECONTENT']._serialized_end=262
  _globals['_TOOLCALL']._serialized_start=265
  _globals['_TOOLCALL']._serialized_end=440
  _globals['_TOOLRESPONSE']._serialized_start=443
  _globals['_TOOLRESPONSE']._serialized_end=654
  _globals['_LLMINVOCATION']._serialized_start=657
  _globals['_LLMINVOCATION']._serialized_end=1301
  _globals['_POLICYDECISION']._serialized_start=1304
  _globals['_POLICYDECISION']._serialized_end=1432
  _globals['_DATAACCESS']._serialized_start=1435
  _globals['_DATAACCESS']._serialized_end=1582
  _globals['_REDACTIONINFO']._serialized_start=1584
  _globals['_REDACTIONINFO']._serialized_end=1672
  _globals['_RETRYINFO']._serialized_start=1674
  _globals['_RETRYINFO']._serialized_end=1770
  _globals['_PERFORMANCEMETRICS']._serialized_start=1773
  _globals['_PERFORMANCEMETRICS']._serialized_end=1951
  _globals['_INFRASTRUCTUREMETRICS']._serialized_start=1954
  _globals['_INFRASTRUCTUREMETRICS']._serialized_end=2145
  _globals['_COSTDETAILS']._serialized_start=2148
  _globals['_COSTDETAILS']._serialized_end=2545
  _globals['_AGENTHANDOFF']._serialized_start=2548
  _globals['_AGENTHANDOFF']._serialized_end=2825
  _globals['_MCPCALL']._serialized_start=2828
  _globals['_MCPCALL']._serialized_end=3146
  _globals['_ERRORINFO']._serialized_start=3149
  _globals['_ERRORINFO']._serialized_end=3336
  _globals['_EVENT']._serialized_start=3339
  _globals['_EVENT']._serialized_end=5368
  _globals['_EVENTBATCH']._serialized_start=5371
  _globals['_EVENTBATCH']._serialized_end=5686
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: chaukas/spec/common/v1/query.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'chaukas/spec/common/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chaukas.spec.common.v1 import events_pb2 as chaukas_dot_spec_dot_common_dot_v1_dot_events__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"chaukas/spec/common/v1/query.proto\x12\x16\x63haukas.spec.common.v1\x1a#chaukas/spec/common/v1/events.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\tTimeRange\x12\x30\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05start\x12,\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03\x65nd\"\xdd\x03\n\x0bQueryFilter\x12\x1b\n\ttenant_id\x18\x01 \x01(\tR\x08tenantId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1d\n\nsession_id\x18\x03 \x01(\tR\tsessionId\x12\x19\n\x08\x61gent_id\x18\x04 \x01(\tR\x07\x61gentId\x12\x17\n\x07span_id\x18\x05 \x01(\tR\x06spanId\x12\x19\n\x08trace_id\x18\x06 \x01(\tR\x07traceId\x12\x37\n\x05types\x18\n \x03(\x0e\x32!.chaukas.spec.common.v1.EventTypeR\x05types\x12?\n\x08statuses\x18\x0b \x03(\x0e\x32#.chaukas.spec.common.v1.EventStatusR\x08statuses\x12@\n\nseverities\x18\x0c \x03(\x0e\x32 .chaukas.spec.common.v1.SeverityR\nseverities\x12\x12\n\x04tags\x18\x14 \x03(\tR\x04tags\x12\x1d\n\ntext_query\x18\x15 \x01(\tR\ttextQuery\x12\x35\n\x04time\x18\x1e \x01(\x0b\x32!.chaukas.spec.common.v1.TimeRangeR\x04time\"\xce\x01\n\x0cQueryRequest\x12;\n\x06\x66ilter\x18\x01 \x01(\x0b\x32#.chaukas.spec.common.v1.QueryFilterR\x06\x66ilter\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x45\n\rorder_by_time\x18\x04 \x01(\x0e\x32!.chaukas.spec.common.v1.SortOrderR\x0borderByTime\"n\n\rQueryResponse\x12\x35\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1d.chaukas.spec.common.v1.EventR\x06\x65vents\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x84\x02\n\x0c\x43\x61pabilities\x12%\n\x0eworm_retention\x18\x01 \x01(\x08R\rwormRetention\x12!\n\x0c\x61udit_proofs\x18\x02 \x01(\x08R\x0b\x61uditProofs\x12+\n\x11\x64istributed_query\x18\x03 \x01(\x08R\x10\x64istributedQuery\x12\x12\n\x04rbac\x18\x04 \x01(\x08R\x04rbac\x12\x10\n\x03sso\x18\x05 \x01(\x08R\x03sso\x12)\n\x10policy_decisions\x18\x06 \x01(\x08R\x0fpolicyDecisions\x12,\n\x12\x64\x61ta_access_events\x18\x07 \x01(\x08R\x10\x64\x61taAccessEvents*P\n\tSortOrder\x12\x1a\n\x16SORT_ORDER_UNSPECIFIED\x10\x00\x12\x12\n\x0eSORT_ORDER_ASC\x10\x01\x12\x13\n\x0fSORT_ORDER_DESC\x10\x02\x42=Z;github.com/chaukasai/chaukas-spec/chaukas/spec/common/v1;v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chaukas.spec.common.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/chaukasai/chaukas-spec/chaukas/spec/common/v1;v1'
  _globals['_SORTORDER']._serialized_start=1305
  _globals['_SORTORDER']._serialized_end=1385
  _globals['_TIMERANGE']._serialized_start=132
  _globals['_TIMERANGE']._serialized_end=239
  _globals['_QUERYFILTER']._serialized_start=242
  _globals['_QUERYFILTER']._serialized_end=719
  _globals['_QUERYREQUEST']._serialized_start=722
  _globals['_QUERYREQUEST']._serialized_end=928
  _globals['_QUERYRESPONSE']._serialized_start=930
  _globals['_QUERYRESPONSE']._serialized_end=1040
  _globals['_CAPABILITIES']._serialized_start=1043
  _globals['_CAPABILITIES']._serialized_end=1303
# @@protoc_insertion_point(module_scope)



import datetime

from chaukas.spec.common.v1 import events_pb2 as _events_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SortOrder(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SORT_ORDER_UNSPECIFIED: _ClassVar[SortOrder]
    SORT_ORDER_ASC: _ClassVar[SortOrder]
    SORT_ORDER_DESC: _ClassVar[SortOrder]
SORT_ORDER_UNSPECIFIED: SortOrder
SORT_ORDER_ASC: SortOrder
SORT_ORDER_DESC: SortOrder

class TimeRange(_message.Message):
    __slots__ = ()
    START_FIELD_NUMBER: _ClassVar[int]
    END_FIELD_NUMBER: _ClassVar[int]
    start: _timestamp_pb2.Timestamp
    end: _timestamp_pb2.Timestamp
    def __init__(self, start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class QueryFilter(_message.Message):
    __slots__ = ()
    TENANT_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    SPAN_ID_FIELD_NUMBER: _ClassVar[int]
    TRACE_ID_FIELD_NUMBER: _ClassVar[int]
    TYPES_FIELD_NUMBER: _ClassVar[int]
    STATUSES_FIELD_NUMBER: _ClassVar[int]
    SEVERITIES_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    TEXT_QUERY_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    tenant_id: str
    project_id: str
    session_id: str
    agent_id: str
    span_id: str
    trace_id: str
    types: _containers.RepeatedScalarFieldContainer[_events_pb2.EventType]
    statuses: _containers.RepeatedScalarFieldContainer[_events_pb2.EventStatus]
    severities: _containers.RepeatedScalarFieldContainer[_events_pb2.Severity]
    tags: _containers.RepeatedScalarFieldContainer[str]
    text_query: str
    time: TimeRange
    def __init__(self, tenant_id: _Optional[str] = ..., project_id: _Optional[str] = ..., session_id: _Optional[str] = ..., agent_id: _Optional[str] = ..., span_id: _Optional[str] = ..., trace_id: _Optional[str] = ..., types: _Optional[_Iterable[_Union[_events_pb2.EventType, str]]] = ..., statuses: _Optional[_Iterable[_Union[_events_pb2.EventStatus, str]]] = ..., severities: _Optional[_Iterable[_Union[_events_pb2.Severity, str]]] = ..., tags: _Optional[_Iterable[str]] = ..., text_query: _Optional[str] = ..., time: _Optional[_Union[TimeRange, _Mapping]] = ...) -> None: ...

class QueryRequest(_message.Message):
    __slots__ = ()
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_TIME_FIELD_NUMBER: _ClassVar[int]
    filter: QueryFilter
    page_size: int
    page_token: str
    order_by_time: SortOrder
    def __init__(self, filter: _Optional[_Union[QueryFilter, _Mapping]] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., order_by_time: _Optional[_Union[SortOrder, str]] = ...) -> None: ...

class QueryResponse(_message.Message):
    __slots__ = ()
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[_events_pb2.Event]
    next_page_token: str
    def __init__(self, events: _Optional[_Iterable[_Union[_events_pb2.Event, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class Capabilities(_message.Message):
    __slots__ = ()
    WORM_RETENTION_FIELD_NUMBER: _ClassVar[int]
    AUDIT_PROOFS_FIELD_NUMBER: _ClassVar[int]
    DISTRIBUTED_QUERY_FIELD_NUMBER: _ClassVar[int]
    RBAC_FIELD_NUMBER: _ClassVar[int]
    SSO_FIELD_NUMBER: _ClassVar[int]
    POLICY_DECISIONS_FIELD_NUMBER: _ClassVar[int]
    DATA_ACCESS_EVENTS_FIELD_NUMBER: _ClassVar[int]
    worm_retention: bool
    audit_proofs: bool
    distributed_query: bool
    rbac: bool
    sso: bool
    policy_decisions: bool
    data_access_events: bool
    def __init__(self, worm_retention: _Optional[bool] = ..., audit_proofs: _Optional[bool] = ..., distributed_query: _Optional[bool] = ..., rbac: _Optional[bool] = ..., sso: _Optional[bool] = ..., policy_decisions: _Optional[bool] = ..., data_access_events: _Optional[bool] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from chaukas.spec.client.v1 import client_pb2 as chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2


class ChaukasClientServiceStub(object):
    """Client-side Chaukas service for SDK integration
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Healthz = channel.unary_unary(
                '/chaukas.spec.client.v1.ChaukasClientService/Healthz',
                request_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.HealthzRequest.SerializeToString,
                response_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.HealthzResponse.FromString,
                _registered_method=True)
        self.GetCapabilities = channel.unary_unary(
                '/chaukas.spec.client.v1.ChaukasClientService/GetCapabilities',
                request_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.GetCapabilitiesRequest.SerializeToString,
                response_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.GetCapabilitiesResponse.FromString,
                _registered_method=True)
        self.IngestEvent = channel.unary_unary(
                '/chaukas.spec.client.v1.ChaukasClientService/IngestEvent',
                request_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventRequest.SerializeToString,
                response_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventResponse.FromString,
                _registered_method=True)
        self.IngestEventBatch = channel.unary_unary(
                '/chaukas.spec.client.v1.ChaukasClientService/IngestEventBatch',
                request_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventBatchRequest.SerializeToString,
                response_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventBatchResponse.FromString,
                _registered_method=True)
        self.QueryEvents = channel.unary_unary(
                '/chaukas.spec.client.v1.ChaukasClientService/QueryEvents',
                request_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.QueryEventsRequest.SerializeToString,
                response_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.QueryEventsResponse.FromString,
                _registered_method=True)


class ChaukasClientServiceServicer(object):
    """Client-side Chaukas service for SDK integration
    """

    def Healthz(self, request, context):
        """Health check endpoint
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCapabilities(self, request, context):
        """Get supported capabilities
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IngestEvent(self, request, context):
        """Ingest a single event
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IngestEventBatch(self, request, context):
        """Ingest a batch of events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryEvents(self, request, context):
        """Query events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ChaukasClientServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Healthz': grpc.unary_unary_rpc_method_handler(
                    servicer.Healthz,
                    request_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.HealthzRequest.FromString,
                    response_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.HealthzResponse.SerializeToString,
            ),
            'GetCapabilities': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCapabilities,
                    request_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.GetCapabilitiesRequest.FromString,
                    response_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.GetCapabilitiesResponse.SerializeToString,
            ),
            'IngestEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.IngestEvent,
                    request_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventRequest.FromString,
                    response_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventResponse.SerializeToString,
            ),
            'IngestEventBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.IngestEventBatch,
                    request_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventBatchRequest.FromString,
                    response_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventBatchResponse.SerializeToString,
            ),
            'QueryEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryEvents,
                    request_deserializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.QueryEventsRequest.FromString,
                    response_serializer=chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.QueryEventsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'chaukas.spec.client.v1.ChaukasClientService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('chaukas.spec.client.v1.ChaukasClientService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ChaukasClientService(object):
    """Client-side Chaukas service for SDK integration
    """

    @staticmethod
    def Healthz(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/chaukas.spec.client.v1.ChaukasClientService/Healthz',
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.HealthzRequest.SerializeToString,
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.HealthzResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCapabilities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/chaukas.spec.client.v1.ChaukasClientService/GetCapabilities',
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.GetCapabilitiesRequest.SerializeToString,
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.GetCapabilitiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IngestEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/chaukas.spec.client.v1.ChaukasClientService/IngestEvent',
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventRequest.SerializeToString,
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IngestEventBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/chaukas.spec.client.v1.ChaukasClientService/IngestEventBatch',
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventBatchRequest.SerializeToString,
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.IngestEventBatchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def QueryEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/chaukas.spec.client.v1.ChaukasClientService/QueryEvents',
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.QueryEventsRequest.SerializeToString,
            chaukas_dot_spec_dot_client_dot_v1_dot_client__pb2.QueryEventsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import datetime

from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_TYPE_UNSPECIFIED: _ClassVar[EventType]
    EVENT_TYPE_SESSION_START: _ClassVar[EventType]
    EVENT_TYPE_SESSION_END: _ClassVar[EventType]
    EVENT_TYPE_AGENT_START: _ClassVar[EventType]
    EVENT_TYPE_AGENT_END: _ClassVar[EventType]
    EVENT_TYPE_AGENT_HANDOFF: _ClassVar[EventType]
    EVENT_TYPE_MODEL_INVOCATION_START: _ClassVar[EventType]
    EVENT_TYPE_MODEL_INVOCATION_END: _ClassVar[EventType]
    EVENT_TYPE_TOOL_CALL_START: _ClassVar[EventType]
    EVENT_TYPE_TOOL_CALL_END: _ClassVar[EventType]
    EVENT_TYPE_MCP_CALL_START: _ClassVar[EventType]
    EVENT_TYPE_MCP_CALL_END: _ClassVar[EventType]
    EVENT_TYPE_INPUT_RECEIVED: _ClassVar[EventType]
    EVENT_TYPE_OUTPUT_EMITTED: _ClassVar[EventType]
    EVENT_TYPE_ERROR: _ClassVar[EventType]
    EVENT_TYPE_RETRY: _ClassVar[EventType]
    EVENT_TYPE_POLICY_DECISION: _ClassVar[EventType]
    EVENT_TYPE_DATA_ACCESS: _ClassVar[EventType]
    EVENT_TYPE_STATE_UPDATE: _ClassVar[EventType]
    EVENT_TYPE_SYSTEM: _ClassVar[EventType]

class EventStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_STATUS_UNSPECIFIED: _ClassVar[EventStatus]
    EVENT_STATUS_STARTED: _ClassVar[EventStatus]
    EVENT_STATUS_IN_PROGRESS: _ClassVar[EventStatus]
    EVENT_STATUS_COMPLETED: _ClassVar[EventStatus]
    EVENT_STATUS_FAILED: _ClassVar[EventStatus]
    EVENT_STATUS_CANCELLED: _ClassVar[EventStatus]

class Severity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SEVERITY_UNSPECIFIED: _ClassVar[Severity]
    SEVERITY_DEBUG: _ClassVar[Severity]
    SEVERITY_INFO: _ClassVar[Severity]
    SEVERITY_WARN: _ClassVar[Severity]
    SEVERITY_ERROR: _ClassVar[Severity]

class Author(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AUTHOR_UNSPECIFIED: _ClassVar[Author]
    AUTHOR_USER: _ClassVar[Author]
    AUTHOR_AGENT: _ClassVar[Author]
    AUTHOR_TOOL: _ClassVar[Author]
    AUTHOR_SYSTEM: _ClassVar[Author]
    AUTHOR_LLM: _ClassVar[Author]
EVENT_TYPE_UNSPECIFIED: EventType
EVENT_TYPE_SESSION_START: EventType
EVENT_TYPE_SESSION_END: EventType
EVENT_TYPE_AGENT_START: EventType
EVENT_TYPE_AGENT_END: EventType
EVENT_TYPE_AGENT_HANDOFF: EventType
EVENT_TYPE_MODEL_INVOCATION_START: EventType
EVENT_TYPE_MODEL_INVOCATION_END: EventType
EVENT_TYPE_TOOL_CALL_START: EventType
EVENT_TYPE_TOOL_CALL_END: EventType
EVENT_TYPE_MCP_CALL_START: EventType
EVENT_TYPE_MCP_CALL_END: EventType
EVENT_TYPE_INPUT_RECEIVED: EventType
EVENT_TYPE_OUTPUT_EMITTED: EventType
EVENT_TYPE_ERROR: EventType
EVENT_TYPE_RETRY: EventType
EVENT_TYPE_POLICY_DECISION: EventType
EVENT_TYPE_DATA_ACCESS: EventType
EVENT_TYPE_STATE_UPDATE: EventType
EVENT_TYPE_SYSTEM: EventType
EVENT_STATUS_UNSPECIFIED: EventStatus
EVENT_STATUS_STARTED: EventStatus
EVENT_STATUS_IN_PROGRESS: EventStatus
EVENT_STATUS_COMPLETED: EventStatus
EVENT_STATUS_FAILED: EventStatus
EVENT_STATUS_CANCELLED: EventStatus
SEVERITY_UNSPECIFIED: Severity
SEVERITY_DEBUG: Severity
SEVERITY_INFO: Severity
SEVERITY_WARN: Severity
SEVERITY_ERROR: Severity
AUTHOR_UNSPECIFIED: Author
AUTHOR_USER: Author
AUTHOR_AGENT: Author
AUTHOR_TOOL: Author
AUTHOR_SYSTEM: Author
AUTHOR_LLM: Author

class MessageContent(_message.Message):
    __slots__ = ()
    ROLE_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    role: str
    text: str
    metadata: _struct_pb2.Struct
    def __init__(self, role: _Optional[str] = ..., text: _Optional[str] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class ToolCall(_message.Message):
    __slots__ = ()
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    AUTH_REQUIRED_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    arguments: _struct_pb2.Struct
    auth_required: bool
    function_name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., arguments: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., auth_required: _Optional[bool] = ..., function_name: _Optional[str] = ...) -> None: ...

class ToolResponse(_message.Message):
    __slots__ = ()
    TOOL_CALL_ID_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_TIME_MS_FIELD_NUMBER: _ClassVar[int]
    HTTP_STATUS_FIELD_NUMBER: _ClassVar[int]
    tool_call_id: str
    output: _struct_pb2.Struct
    error_message: str
    execution_time_ms: float
    http_status: int
    def __init__(self, tool_call_id: _Optional[str] = ..., output: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., error_message: _Optional[str] = ..., execution_time_ms: _Optional[float] = ..., http_status: _Optional[int] = ...) -> None: ...

class LLMInvocation(_message.Message):
    __slots__ = ()
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    PROMPT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    MAX_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TOP_P_FIELD_NUMBER: _ClassVar[int]
    FREQUENCY_PENALTY_FIELD_NUMBER: _ClassVar[int]
    PRESENCE_PENALTY_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    FINISH_REASON_FIELD_NUMBER: _ClassVar[int]
    provider: str
    model: str
    request: _struct_pb2.Struct
    response: _struct_pb2.Struct
    prompt_tokens: int
    completion_tokens: int
    total_tokens: int
    temperature: float
    max_tokens: int
    top_p: float
    frequency_penalty: float
    presence_penalty: float
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    duration_ms: float
    finish_reason: str
    def __init__(self, provider: _Optional[str] = ..., model: _Optional[str] = ..., request: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., response: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., prompt_tokens: _Optional[int] = ..., completion_tokens: _Optional[int] = ..., total_tokens: _Optional[int] = ..., temperature: _Optional[float] = ..., max_tokens: _Optional[int] = ..., top_p: _Optional[float] = ..., frequency_penalty: _Optional[float] = ..., presence_penalty: _Optional[float] = ..., start_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., duration_ms: _Optional[float] = ..., finish_reason: _Optional[str] = ...) -> None: ...

class PolicyDecision(_message.Message):
    __slots__ = ()
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    OUTCOME_FIELD_NUMBER: _ClassVar[int]
    RULE_IDS_FIELD_NUMBER: _ClassVar[int]
    RATIONALE_FIELD_NUMBER: _ClassVar[int]
    policy_id: str
    outcome: str
    rule_ids: _containers.RepeatedScalarFieldContainer[str]
    rationale: str
    def __init__(self, policy_id: _Optional[str] = ..., outcome: _Optional[str] = ..., rule_ids: _Optional[_Iterable[str]] = ..., rationale: _Optional[str] = ...) -> None: ...

class DataAccess(_message.Message):
    __slots__ = ()
    DATASOURCE_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_IDS_FIELD_NUMBER: _ClassVar[int]
    CHUNK_IDS_FIELD_NUMBER: _ClassVar[int]
    PII_CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    datasource: str
    document_ids: _containers.RepeatedScalarFieldContainer[str]
    chunk_ids: _containers.RepeatedScalarFieldContainer[str]
    pii_categories: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, datasource: _Optional[str] = ..., document_ids: _Optional[_Iterable[str]] = ..., chunk_ids: _Optional[_Iterable[str]] = ..., pii_categories: _Optional[_Iterable[str]] = ...) -> None: ...

class RedactionInfo(_message.Message):
    __slots__ = ()
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    SALT_ID_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.RepeatedScalarFieldContainer[str]
    method: str
    salt_id: str
    def __init__(self, fields: _Optional[_Iterable[str]] = ..., method: _Optional[str] = ..., salt_id: _Optional[str] = ...) -> None: ...

class RetryInfo(_message.Message):
    __slots__ = ()
    ATTEMPT_FIELD_NUMBER: _ClassVar[int]
    STRATEGY_FIELD_NUMBER: _ClassVar[int]
    BACKOFF_MS_FIELD_NUMBER: _ClassVar[int]
    attempt: int
    strategy: str
    backoff_ms: int
    def __init__(self, attempt: _Optional[int] = ..., strategy: _Optional[str] = ..., backoff_ms: _Optional[int] = ...) -> None: ...

class PerformanceMetrics(_message.Message):
    __slots__ = ()
    CPU_PERCENT_FIELD_NUMBER: _ClassVar[int]
    MEMORY_MB_FIELD_NUMBER: _ClassVar[int]
    DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    THROUGHPUT_FIELD_NUMBER: _ClassVar[int]
    LATENCY_MS_FIELD_NUMBER: _ClassVar[int]
    cpu_percent: float
    memory_mb: float
    duration_ms: float
    throughput: float
    latency_ms: float
    def __init__(self, cpu_percent: _Optional[float] = ..., memory_mb: _Optional[float] = ..., duration_ms: _Optional[float] = ..., throughput: _Optional[float] = ..., latency_ms: _Optional[float] = ...) -> None: ...

class InfrastructureMetrics(_message.Message):
    __slots__ = ()
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    HOST_FIELD_NUMBER: _ClassVar[int]
    PROCESS_ID_FIELD_NUMBER: _ClassVar[int]
    THREAD_ID_FIELD_NUMBER: _ClassVar[int]
    resource_type: str
    metrics: _struct_pb2.Struct
    host: str
    process_id: int
    thread_id: str
    def __init__(self, resource_type: _Optional[str] = ..., metrics: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., host: _Optional[str] = ..., process_id: _Optional[int] = ..., thread_id: _Optional[str] = ...) -> None: ...

class CostDetails(_message.Message):
    __slots__ = ()
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TOKENS_FIELD_NUMBER: _ClassVar[int]
    INPUT_COST_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_COST_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COST_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    INPUT_RATE_PER_TOKEN_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_RATE_PER_TOKEN_FIELD_NUMBER: _ClassVar[int]
    provider: str
    service: str
    input_tokens: int
    output_tokens: int
    total_tokens: int
    input_cost: float
    output_cost: float
    total_cost: float
    currency: str
    input_rate_per_token: float
    output_rate_per_token: float
    def __init__(self, provider: _Optional[str] = ..., service: _Optional[str] = ..., input_tokens: _Optional[int] = ..., output_tokens: _Optional[int] = ..., total_tokens: _Optional[int] = ..., input_cost: _Optional[float] = ..., output_cost: _Optional[float] = ..., total_cost: _Optional[float] = ..., currency: _Optional[str] = ..., input_rate_per_token: _Optional[float] = ..., output_rate_per_token: _Optional[float] = ...) -> None: ...

class AgentHandoff(_message.Message):
    __slots__ = ()
    FROM_AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    FROM_AGENT_NAME_FIELD_NUMBER: _ClassVar[int]
    TO_AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    TO_AGENT_NAME_FIELD_NUMBER: _ClassVar[int]
    HANDOFF_DATA_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    HANDOFF_TYPE_FIELD_NUMBER: _ClassVar[int]
    from_agent_id: str
    from_agent_name: str
    to_agent_id: str
    to_agent_name: str
    handoff_data: _struct_pb2.Struct
    reason: str
    handoff_type: str
    def __init__(self, from_agent_id: _Optional[str] = ..., from_agent_name: _Optional[str] = ..., to_agent_id: _Optional[str] = ..., to_agent_name: _Optional[str] = ..., handoff_data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., reason: _Optional[str] = ..., handoff_type: _Optional[str] = ...) -> None: ...

class MCPCall(_message.Message):
    __slots__ = ()
    SERVER_NAME_FIELD_NUMBER: _ClassVar[int]
    SERVER_URL_FIELD_NUMBER: _ClassVar[int]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_TIME_MS_FIELD_NUMBER: _ClassVar[int]
    server_name: str
    server_url: str
    operation: str
    method: str
    request: _struct_pb2.Struct
    response: _struct_pb2.Struct
    protocol_version: str
    execution_time_ms: float
    def __init__(self, server_name: _Optional[str] = ..., server_url: _Optional[str] = ..., operation: _Optional[str] = ..., method: _Optional[str] = ..., request: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., response: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., protocol_version: _Optional[str] = ..., execution_time_ms: _Optional[float] = ...) -> None: ...

class ErrorInfo(_message.Message):
    __slots__ = ()
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    STACK_TRACE_FIELD_NUMBER: _ClassVar[int]
    RECOVERABLE_FIELD_NUMBER: _ClassVar[int]
    RECOVERY_ACTION_FIELD_NUMBER: _ClassVar[int]
    error_message: str
    error_code: str
    stack_trace: str
    recoverable: bool
    recovery_action: str
    def __init__(self, error_message: _Optional[str] = ..., error_code: _Optional[str] = ..., stack_trace: _Optional[str] = ..., recoverable: _Optional[bool] = ..., recovery_action: _Optional[str] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ()
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    TENANT_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    SPAN_ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_SPAN_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SEVERITY_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    AUTHOR_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    AGENT_NAME_FIELD_NUMBER: _ClassVar[int]
    INVOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_ID_FIELD_NUMBER: _ClassVar[int]
    IS_PARTIAL_FIELD_NUMBER: _ClassVar[int]
    IS_FINAL_FIELD_NUMBER: _ClassVar[int]
    HASH_PREV_FIELD_NUMBER: _ClassVar[int]
    CONTENT_HASH_FIELD_NUMBER: _ClassVar[int]
    WORM_PROOF_ID_FIELD_NUMBER: _ClassVar[int]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    TRACE_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TOOL_CALL_FIELD_NUMBER: _ClassVar[int]
    TOOL_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    LLM_INVOCATION_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    DATA_ACCESS_FIELD_NUMBER: _ClassVar[int]
    STATE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    AGENT_HANDOFF_FIELD_NUMBER: _ClassVar[int]
    MCP_CALL_FIELD_NUMBER: _ClassVar[int]
    RETRY_FIELD_NUMBER: _ClassVar[int]
    REDACTION_FIELD_NUMBER: _ClassVar[int]
    PII_CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    PERFORMANCE_FIELD_NUMBER: _ClassVar[int]
    INFRASTRUCTURE_FIELD_NUMBER: _ClassVar[int]
    COST_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    tenant_id: str
    project_id: str
    session_id: str
    span_id: str
    parent_span_id: str
    type: EventType
    severity: Severity
    status: EventStatus
    author: Author
    timestamp: _timestamp_pb2.Timestamp
    agent_id: str
    agent_name: str
    invocation_id: str
    response_id: str
    is_partial: bool
    is_final: bool
    hash_prev: str
    content_hash: str
    worm_proof_id: str
    branch: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    trace_id: str
    message: MessageContent
    tool_call: ToolCall
    tool_response: ToolResponse
    llm_invocation: LLMInvocation
    policy: PolicyDecision
    data_access: DataAccess
    state_update: _struct_pb2.Struct
    error: ErrorInfo
    agent_handoff: AgentHandoff
    mcp_call: MCPCall
    retry: RetryInfo
    redaction: RedactionInfo
    pii_categories: _containers.RepeatedScalarFieldContainer[str]
    performance: PerformanceMetrics
    infrastructure: InfrastructureMetrics
    cost: CostDetails
    metadata: _struct_pb2.Struct
    extensions: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, event_id: _Optional[str] = ..., tenant_id: _Optional[str] = ..., project_id: _Optional[str] = ..., session_id: _Optional[str] = ..., span_id: _Optional[str] = ..., parent_span_id: _Optional[str] = ..., type: _Optional[_Union[EventType, str]] = ..., severity: _Optional[_Union[Severity, str]] = ..., status: _Optional[_Union[EventStatus, str]] = ..., author: _Optional[_Union[Author, str]] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., agent_id: _Optional[str] = ..., agent_name: _Optional[str] = ..., invocation_id: _Optional[str] = ..., response_id: _Optional[str] = ..., is_partial: _Optional[bool] = ..., is_final: _Optional[bool] = ..., hash_prev: _Optional[str] = ..., content_hash: _Optional[str] = ..., worm_proof_id: _Optional[str] = ..., branch: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., trace_id: _Optional[str] = ..., message: _Optional[_Union[MessageContent, _Mapping]] = ..., tool_call: _Optional[_Union[ToolCall, _Mapping]] = ..., tool_response: _Optional[_Union[ToolResponse, _Mapping]] = ..., llm_invocation: _Optional[_Union[LLMInvocation, _Mapping]] = ..., policy: _Optional[_Union[PolicyDecision, _Mapping]] = ..., data_access: _Optional[_Union[DataAccess, _Mapping]] = ..., state_update: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., error: _Optional[_Union[ErrorInfo, _Mapping]] = ..., agent_handoff: _Optional[_Union[AgentHandoff, _Mapping]] = ..., mcp_call: _Optional[_Union[MCPCall, _Mapping]] = ..., retry: _Optional[_Union[RetryInfo, _Mapping]] = ..., redaction: _Optional[_Union[RedactionInfo, _Mapping]] = ..., pii_categories: _Optional[_Iterable[str]] = ..., performance: _Optional[_Union[PerformanceMetrics, _Mapping]] = ..., infrastructure: _Optional[_Union[InfrastructureMetrics, _Mapping]] = ..., cost: _Optional[_Union[CostDetails, _Mapping]] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., extensions: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...

class EventBatch(_message.Message):
    __slots__ = ()
    BATCH_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COST_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    batch_id: str
    timestamp: _timestamp_pb2.Timestamp
    events: _containers.RepeatedCompositeFieldContainer[Event]
    metadata: _struct_pb2.Struct
    total_cost: float
    total_tokens: int
    total_duration_ms: float
    def __init__(self, batch_id: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., total_cost: _Optional[float] = ..., total_tokens: _Optional[int] = ..., total_duration_ms: _Optional[float] = ...) -> None: ...
